Page 17 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 17

Home

    And they cast dust on their heads, and cried, weeping
    and wailing, saying, Alas, alas, that great city, wherein
    were made rich all that had ships in the sea by reason of

    We att it

    And the light of a candle shall shine no more at all in
    thee; and the voice of the bridegroom and of the bride
    shall be heard no more at all in thee: for thy merchants
    were the great men of the earth; for by thy sorceries
    were all nations deceived.

    And in her was found the blood of prophets, and of
    saints, and of all that were slain upon the earth.

    n diut ) 10.nNA

    For true and righteous are his judgments: for he hath
    judged the great whore, which did corrupt the earth with
    her fornication,. . .

    12

    The Secret Side of History

    4. Both were great centers of commerce.

    her costliness!

    Revelation 18:19

    5. Both were allied with spiritual evil.

    Revelation 18:23

    6. Both killed great numbers, especially believers.

    Revelation 18:24

    7. Both were a corrupting influence.

    Revelation 19:2

    In condemning Ancient Babylon, the Old Testament

    prophet Jeremiah used language very similar to that used